'use strict';
delete global.Observable;
require('core-js');
// eslint-disable-next-line import/no-unresolved -- generated later
require('../bundles/observables-tests/default').runTests(global.Observable);
